changeset 72144:2824d0383afd

(which-function): Fix documentation/comment typo.
author Nick Roberts <nickrob@snap.net.nz>
date Thu, 27 Jul 2006 12:18:03 +0000
parents c72f78a4a1c1
children 947c480fb7e0
files lisp/progmodes/which-func.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/which-func.el	Thu Jul 27 12:17:38 2006 +0000
+++ b/lisp/progmodes/which-func.el	Thu Jul 27 12:18:03 2006 +0000
@@ -262,11 +262,11 @@
 
 (defun which-function ()
   "Return current function name based on point.
-Uses `which-function-functions', `imenu--index-alist'
+Uses `which-func-functions', `imenu--index-alist'
 or `add-log-current-defun-function'.
 If no function name is found, return nil."
   (let ((name
 	 ;; Try the `which-function-functions' functions first.
 	 (run-hook-with-args-until-success 'which-func-functions)))
 
     ;; If Imenu is loaded, try to make an index alist with it.
@@ -262,11 +262,11 @@
 If no function name is found, return nil."
   (let ((name
-	 ;; Try the `which-function-functions' functions first.
+	 ;; Try the `which-func-functions' functions first.
 	 (run-hook-with-args-until-success 'which-func-functions)))
 